You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@pekko.apache.org by jr...@apache.org on 2023/03/06 13:58:55 UTC

[incubator-pekko-http] branch main updated: regenerate SSL certificates with new example domain name (#108)

This is an automated email from the ASF dual-hosted git repository.

jrudolph pushed a commit to branch main
in repository https://gitbox.apache.org/repos/asf/incubator-pekko-http.git


The following commit(s) were added to refs/heads/main by this push:
     new 4418598fd regenerate SSL certificates with new example domain name (#108)
4418598fd is described below

commit 4418598fd6ff7a0ab62d747d7dafee4dbda28a64
Author: Johannes Rudolph <jo...@gmail.com>
AuthorDate: Mon Mar 6 14:58:48 2023 +0100

    regenerate SSL certificates with new example domain name (#108)
---
 http-core/src/test/resources/keys/README.md        |   2 +-
 http-core/src/test/resources/keys/chain.pem        |  34 ++++++++++-----------
 http-core/src/test/resources/keys/server.crt       |  34 ++++++++++-----------
 http-core/src/test/resources/keys/server.p12       | Bin 3384 -> 3510 bytes
 .../engine/client/ClientCancellationSpec.scala     |   4 +--
 .../engine/client/HostConnectionPoolSpec.scala     |   7 +++--
 .../client/TlsEndpointVerificationSpec.scala       |  18 +++++------
 .../pekko/http/impl/util/ExampleHttpContexts.scala |   2 +-
 .../pekko/http/scaladsl/ClientServerSpec.scala     |   8 ++---
 .../http/scaladsl/GracefulTerminationSpec.scala    |   4 +--
 .../main/resources/httpsDemoKeys/keys/README.md    |   2 +-
 .../impl/engine/http2/Http2ClientServerSpec.scala  |   2 +-
 .../engine/http2/Http2PersistentClientSpec.scala   |   2 +-
 .../http/impl/engine/http2/TelemetrySpiSpec.scala  |   4 +--
 14 files changed, 62 insertions(+), 61 deletions(-)

diff --git a/http-core/src/test/resources/keys/README.md b/http-core/src/test/resources/keys/README.md
index 4381eb2eb..ab5dbf5aa 100644
--- a/http-core/src/test/resources/keys/README.md
+++ b/http-core/src/test/resources/keys/README.md
@@ -25,7 +25,7 @@ openssl req -x509 -new -nodes -key rootCA.key -days 3560 -out rootCA.crt
 openssl genrsa -out server.key 2048
 ```
 
-# Create server CSR (you need to set the common name CN to "akka.example.org"):
+# Create server CSR (you need to set the common name CN to "pekko.example.org"):
 
 ```
 openssl req -new -key server.key -out server.csr
diff --git a/http-core/src/test/resources/keys/chain.pem b/http-core/src/test/resources/keys/chain.pem
index 766871eba..078ccaa72 100644
--- a/http-core/src/test/resources/keys/chain.pem
+++ b/http-core/src/test/resources/keys/chain.pem
@@ -1,21 +1,21 @@
 -----BEGIN CERTIFICATE-----
-MIIDITCCAgkCCQCo8H6OcPrArzANBgkqhkiG9w0BAQsFADBFMQswCQYDVQQGEwJB
-VTETMBEGA1UECAwKU29tZS1TdGF0ZTEhMB8GA1UECgwYSW50ZXJuZXQgV2lkZ2l0
-cyBQdHkgTHRkMB4XDTE1MDcyMzA5NTEyMloXDTI1MDQyMTA5NTEyMlowYDELMAkG
-A1UEBhMCQVUxEzARBgNVBAgMClNvbWUtU3RhdGUxITAfBgNVBAoMGEludGVybmV0
-IFdpZGdpdHMgUHR5IEx0ZDEZMBcGA1UEAwwQYWtrYS5leGFtcGxlLm9yZzCCASIw
-DQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANMy/wgrSYVhVtu9OGbo2rSKauiz
-5V56X4uCqtCHF9UeHtnVtFLCBMa+pimOS+UyUAT4mbBsxW22BhoNUBZ15KPxltyD
-yEsqNCKwWGxL3r8AXQtze2MEpTl22Lvp/iCTXO1vbML/+9r3uqUjw/AAP9HwF9Wd
-j/yOrs6q8WE4sfc48iOj6N60/h2pRfn2WNJmo9W9FLC53NznixfsG5oN6Jmb9RM+
-fMHYXLfL/Vt6NrgVX1uqHt9HvuoxfNKhhXE5VU8bNfFfzPYvIt4aZXGxO15vEqsq
-OaZ7YJyKr1oFfJC8LmE5xPa3GHToCqmkdMXQK38mpslMQWlQLYnmkS5Qzv8CAwEA
-ATANBgkqhkiG9w0BAQsFAAOCAQEAEPDd1gAF9q2LtoZqTdcwmeBjdbT7n0WDRSuI
-BzQ/qKjvymwpFKQ0pZSPUyaw2qfRRiTQ/QTbqYep2mhvl5n+gW3ifTp83zgTGKH/
-3sDlX0HPSCBYCDy2gP/AOIgV/57ADMpEkTlz8yyLMH+pLDAoNFIPwy7blAkq+ULQ
-y6TfEBmZXoemSaIh5tRnexCD+pTvL4MRrGlBEoxdejDnIAt4n6BxmF0b4hKg8uta
-UvivA85lBKzWUoR/Vam5/SC8jtcyLt9RThRcNSj6zP6s5d+o+8PLznrSEadAtfD9
-0q+t4TYF81tClEEgGruVPNL4WIpDniOfw9AJgQNVJGfy5TKY1Q==
+MIIDBDCCAewCFCWEZRqRC0YvlLgve2sPHaE8XmzuMA0GCSqGSIb3DQEBCwUAMEUx
+CzAJBgNVBAYTAkFVMRMwEQYDVQQIDApTb21lLVN0YXRlMSEwHwYDVQQKDBhJbnRl
+cm5ldCBXaWRnaXRzIFB0eSBMdGQwHhcNMjMwMzA2MTEwNjU4WhcNMzIxMjAzMTEw
+NjU4WjA4MRowGAYDVQQKDBFBcGFjaGUgRm91bmRhdGlvbjEaMBgGA1UEAwwRcGVr
+a28uZXhhbXBsZS5vcmcwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDT
+Mv8IK0mFYVbbvThm6Nq0imros+Veel+LgqrQhxfVHh7Z1bRSwgTGvqYpjkvlMlAE
++JmwbMVttgYaDVAWdeSj8Zbcg8hLKjQisFhsS96/AF0Lc3tjBKU5dti76f4gk1zt
+b2zC//va97qlI8PwAD/R8BfVnY/8jq7OqvFhOLH3OPIjo+jetP4dqUX59ljSZqPV
+vRSwudzc54sX7BuaDeiZm/UTPnzB2Fy3y/1beja4FV9bqh7fR77qMXzSoYVxOVVP
+GzXxX8z2LyLeGmVxsTtebxKrKjmme2Cciq9aBXyQvC5hOcT2txh06AqppHTF0Ct/
+JqbJTEFpUC2J5pEuUM7/AgMBAAEwDQYJKoZIhvcNAQELBQADggEBADXOb5GvDN8E
+qQjLzl5YsTPejP5AZ1i6PdwaHqx9sKkKwmyc64yGnORmdNksN7A90cP/LsYe7Ob5
+5WfAVAHpMKkXN2GdABW/7/7jji87pUHQspw/Sw4V7DdAETkABV0QD/RBMvjyCc2v
+TWibRqDLiXmCGXwzTyV8p7rrPWpiLvsEjv2IjB/qU5W7aTsKudVpooVPR/q+dg+5
+y53duvD+6FVWt1si9/Fsu7G1CJ3cbpOZ6iqo/gPrFWmpizKGaAyDEFItWfOCKhU0
+vOUDLMKa4EGslLuzeMJZMtx4OdTQv3YsEEB3YRZvl7fY4RTo5ToyU+MNwJ7nwoJm
+RcEnxZHP8Xg=
 -----END CERTIFICATE-----
 -----BEGIN CERTIFICATE-----
 MIIDXTCCAkWgAwIBAgIJANYwx08wP3STMA0GCSqGSIb3DQEBCwUAMEUxCzAJBgNV
diff --git a/http-core/src/test/resources/keys/server.crt b/http-core/src/test/resources/keys/server.crt
index 4395b589d..a9a71cb5d 100644
--- a/http-core/src/test/resources/keys/server.crt
+++ b/http-core/src/test/resources/keys/server.crt
@@ -1,19 +1,19 @@
 -----BEGIN CERTIFICATE-----
-MIIDITCCAgkCCQCo8H6OcPrArzANBgkqhkiG9w0BAQsFADBFMQswCQYDVQQGEwJB
-VTETMBEGA1UECAwKU29tZS1TdGF0ZTEhMB8GA1UECgwYSW50ZXJuZXQgV2lkZ2l0
-cyBQdHkgTHRkMB4XDTE1MDcyMzA5NTEyMloXDTI1MDQyMTA5NTEyMlowYDELMAkG
-A1UEBhMCQVUxEzARBgNVBAgMClNvbWUtU3RhdGUxITAfBgNVBAoMGEludGVybmV0
-IFdpZGdpdHMgUHR5IEx0ZDEZMBcGA1UEAwwQYWtrYS5leGFtcGxlLm9yZzCCASIw
-DQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANMy/wgrSYVhVtu9OGbo2rSKauiz
-5V56X4uCqtCHF9UeHtnVtFLCBMa+pimOS+UyUAT4mbBsxW22BhoNUBZ15KPxltyD
-yEsqNCKwWGxL3r8AXQtze2MEpTl22Lvp/iCTXO1vbML/+9r3uqUjw/AAP9HwF9Wd
-j/yOrs6q8WE4sfc48iOj6N60/h2pRfn2WNJmo9W9FLC53NznixfsG5oN6Jmb9RM+
-fMHYXLfL/Vt6NrgVX1uqHt9HvuoxfNKhhXE5VU8bNfFfzPYvIt4aZXGxO15vEqsq
-OaZ7YJyKr1oFfJC8LmE5xPa3GHToCqmkdMXQK38mpslMQWlQLYnmkS5Qzv8CAwEA
-ATANBgkqhkiG9w0BAQsFAAOCAQEAEPDd1gAF9q2LtoZqTdcwmeBjdbT7n0WDRSuI
-BzQ/qKjvymwpFKQ0pZSPUyaw2qfRRiTQ/QTbqYep2mhvl5n+gW3ifTp83zgTGKH/
-3sDlX0HPSCBYCDy2gP/AOIgV/57ADMpEkTlz8yyLMH+pLDAoNFIPwy7blAkq+ULQ
-y6TfEBmZXoemSaIh5tRnexCD+pTvL4MRrGlBEoxdejDnIAt4n6BxmF0b4hKg8uta
-UvivA85lBKzWUoR/Vam5/SC8jtcyLt9RThRcNSj6zP6s5d+o+8PLznrSEadAtfD9
-0q+t4TYF81tClEEgGruVPNL4WIpDniOfw9AJgQNVJGfy5TKY1Q==
+MIIDBDCCAewCFCWEZRqRC0YvlLgve2sPHaE8XmzuMA0GCSqGSIb3DQEBCwUAMEUx
+CzAJBgNVBAYTAkFVMRMwEQYDVQQIDApTb21lLVN0YXRlMSEwHwYDVQQKDBhJbnRl
+cm5ldCBXaWRnaXRzIFB0eSBMdGQwHhcNMjMwMzA2MTEwNjU4WhcNMzIxMjAzMTEw
+NjU4WjA4MRowGAYDVQQKDBFBcGFjaGUgRm91bmRhdGlvbjEaMBgGA1UEAwwRcGVr
+a28uZXhhbXBsZS5vcmcwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDT
+Mv8IK0mFYVbbvThm6Nq0imros+Veel+LgqrQhxfVHh7Z1bRSwgTGvqYpjkvlMlAE
++JmwbMVttgYaDVAWdeSj8Zbcg8hLKjQisFhsS96/AF0Lc3tjBKU5dti76f4gk1zt
+b2zC//va97qlI8PwAD/R8BfVnY/8jq7OqvFhOLH3OPIjo+jetP4dqUX59ljSZqPV
+vRSwudzc54sX7BuaDeiZm/UTPnzB2Fy3y/1beja4FV9bqh7fR77qMXzSoYVxOVVP
+GzXxX8z2LyLeGmVxsTtebxKrKjmme2Cciq9aBXyQvC5hOcT2txh06AqppHTF0Ct/
+JqbJTEFpUC2J5pEuUM7/AgMBAAEwDQYJKoZIhvcNAQELBQADggEBADXOb5GvDN8E
+qQjLzl5YsTPejP5AZ1i6PdwaHqx9sKkKwmyc64yGnORmdNksN7A90cP/LsYe7Ob5
+5WfAVAHpMKkXN2GdABW/7/7jji87pUHQspw/Sw4V7DdAETkABV0QD/RBMvjyCc2v
+TWibRqDLiXmCGXwzTyV8p7rrPWpiLvsEjv2IjB/qU5W7aTsKudVpooVPR/q+dg+5
+y53duvD+6FVWt1si9/Fsu7G1CJ3cbpOZ6iqo/gPrFWmpizKGaAyDEFItWfOCKhU0
+vOUDLMKa4EGslLuzeMJZMtx4OdTQv3YsEEB3YRZvl7fY4RTo5ToyU+MNwJ7nwoJm
+RcEnxZHP8Xg=
 -----END CERTIFICATE-----
diff --git a/http-core/src/test/resources/keys/server.p12 b/http-core/src/test/resources/keys/server.p12
index d72cc9f3d..48e199543 100644
Binary files a/http-core/src/test/resources/keys/server.p12 and b/http-core/src/test/resources/keys/server.p12 differ
diff --git a/http-core/src/test/scala/org/apache/pekko/http/impl/engine/client/ClientCancellationSpec.scala b/http-core/src/test/scala/org/apache/pekko/http/impl/engine/client/ClientCancellationSpec.scala
index dc98b7ef0..399ce49db 100644
--- a/http-core/src/test/scala/org/apache/pekko/http/impl/engine/client/ClientCancellationSpec.scala
+++ b/http-core/src/test/scala/org/apache/pekko/http/impl/engine/client/ClientCancellationSpec.scala
@@ -42,7 +42,7 @@ class ClientCancellationSpec extends PekkoSpecWithMaterializer {
     "support cancellation in simple outgoing connection with TLS" in Utils.assertAllStagesStopped(new TestSetup {
       pending
       testCase(
-        Http().connectionTo("akka.example.org")
+        Http().connectionTo("pekko.example.org")
           .withClientConnectionSettings(settingsWithProxyTransport)
           .withCustomHttpsConnectionContext(ExampleHttpContexts.exampleClientContext)
           .https())
@@ -52,7 +52,7 @@ class ClientCancellationSpec extends PekkoSpecWithMaterializer {
       testCase(
         Flow[HttpRequest]
           .map((_, ()))
-          .via(Http().cachedHostConnectionPoolHttps("akka.example.org", 443,
+          .via(Http().cachedHostConnectionPoolHttps("pekko.example.org", 443,
             settings = ConnectionPoolSettings(system).withConnectionSettings(settingsWithProxyTransport),
             connectionContext = ExampleHttpContexts.exampleClientContext))
           .map(_._1.get))
diff --git a/http-core/src/test/scala/org/apache/pekko/http/impl/util/ExampleHttpContexts.scala b/http-core/src/test/scala/org/apache/pekko/http/impl/util/ExampleHttpContexts.scala
index 7490108d1..34a6a5673 100644
--- a/http-core/src/test/scala/org/apache/pekko/http/impl/util/ExampleHttpContexts.scala
+++ b/http-core/src/test/scala/org/apache/pekko/http/impl/util/ExampleHttpContexts.scala
@@ -77,7 +77,7 @@ object ExampleHttpContexts {
 
   /**
    * A client transport that will rewrite the target address to a fixed address. This can be used
-   * to pretend to connect to akka.example.org which is required to connect to the example server certificate.
+   * to pretend to connect to pekko.example.org which is required to connect to the example server certificate.
    */
   def proxyTransport(realAddress: InetSocketAddress): ClientTransport =
     new ClientTransport {
diff --git a/http-core/src/test/scala/org/apache/pekko/http/scaladsl/GracefulTerminationSpec.scala b/http-core/src/test/scala/org/apache/pekko/http/scaladsl/GracefulTerminationSpec.scala
index 698cfb4d6..cbd21fb70 100644
--- a/http-core/src/test/scala/org/apache/pekko/http/scaladsl/GracefulTerminationSpec.scala
+++ b/http-core/src/test/scala/org/apache/pekko/http/scaladsl/GracefulTerminationSpec.scala
@@ -25,7 +25,7 @@ import pekko.http.scaladsl.model.headers.{ `Content-Encoding`, Connection, HttpE
 import pekko.http.scaladsl.settings.ClientConnectionSettings
 import pekko.http.scaladsl.settings.{ ConnectionPoolSettings, ServerSettings }
 import pekko.stream.scaladsl._
-import pekko.stream.testkit.TestSubscriber.{ OnComplete, OnError }
+import pekko.stream.testkit.TestSubscriber.OnError
 import pekko.stream.testkit.scaladsl.{ StreamTestKit, TestSink }
 import pekko.stream.{ Server => _, _ }
 import pekko.testkit._
@@ -324,7 +324,7 @@ class GracefulTerminationSpec
     var idleTimeoutBaseForUniqueness = 10
 
     def nextRequest() =
-      HttpRequest(uri = s"https://akka.example.org/${counter.incrementAndGet()}", entity = "hello-from-client")
+      HttpRequest(uri = s"https://pekko.example.org/${counter.incrementAndGet()}", entity = "hello-from-client")
     val serverConnectionContext = ExampleHttpContexts.exampleServerContext
     val clientConnectionContext = ExampleHttpContexts.exampleClientContext
 
diff --git a/http-tests/src/main/resources/httpsDemoKeys/keys/README.md b/http-tests/src/main/resources/httpsDemoKeys/keys/README.md
index 4381eb2eb..ab5dbf5aa 100644
--- a/http-tests/src/main/resources/httpsDemoKeys/keys/README.md
+++ b/http-tests/src/main/resources/httpsDemoKeys/keys/README.md
@@ -25,7 +25,7 @@ openssl req -x509 -new -nodes -key rootCA.key -days 3560 -out rootCA.crt
 openssl genrsa -out server.key 2048
 ```
 
-# Create server CSR (you need to set the common name CN to "akka.example.org"):
+# Create server CSR (you need to set the common name CN to "pekko.example.org"):
 
 ```
 openssl req -new -key server.key -out server.csr
diff --git a/http2-tests/src/test/scala/org/apache/pekko/http/impl/engine/http2/Http2ClientServerSpec.scala b/http2-tests/src/test/scala/org/apache/pekko/http/impl/engine/http2/Http2ClientServerSpec.scala
index 4a8bedfaa..0d847ac2b 100644
--- a/http2-tests/src/test/scala/org/apache/pekko/http/impl/engine/http2/Http2ClientServerSpec.scala
+++ b/http2-tests/src/test/scala/org/apache/pekko/http/impl/engine/http2/Http2ClientServerSpec.scala
@@ -169,7 +169,7 @@ class Http2ClientServerSpec extends PekkoSpecWithMaterializer(
         .withSettings(serverSettings)
         .bind(handler).futureValue
     lazy val clientFlow =
-      Http().connectionTo("akka.example.org")
+      Http().connectionTo("pekko.example.org")
         .withCustomHttpsConnectionContext(ExampleHttpContexts.exampleClientContext)
         .withClientConnectionSettings(
           clientSettings.withTransport(ExampleHttpContexts.proxyTransport(binding.localAddress)))
diff --git a/http2-tests/src/test/scala/org/apache/pekko/http/impl/engine/http2/Http2PersistentClientSpec.scala b/http2-tests/src/test/scala/org/apache/pekko/http/impl/engine/http2/Http2PersistentClientSpec.scala
index cbb6a3bbf..f6acf9a3c 100644
--- a/http2-tests/src/test/scala/org/apache/pekko/http/impl/engine/http2/Http2PersistentClientSpec.scala
+++ b/http2-tests/src/test/scala/org/apache/pekko/http/impl/engine/http2/Http2PersistentClientSpec.scala
@@ -404,7 +404,7 @@ abstract class Http2PersistentClientSpec(tls: Boolean) extends PekkoSpecWithMate
     object client {
 
       lazy val clientFlow = {
-        val builder = Http().connectionTo("akka.example.org")
+        val builder = Http().connectionTo("pekko.example.org")
           .withCustomHttpsConnectionContext(ExampleHttpContexts.exampleClientContext)
           .withClientConnectionSettings(clientSettings)
 
diff --git a/http2-tests/src/test/scala/org/apache/pekko/http/impl/engine/http2/TelemetrySpiSpec.scala b/http2-tests/src/test/scala/org/apache/pekko/http/impl/engine/http2/TelemetrySpiSpec.scala
index 3aaa7ba19..3cd752894 100644
--- a/http2-tests/src/test/scala/org/apache/pekko/http/impl/engine/http2/TelemetrySpiSpec.scala
+++ b/http2-tests/src/test/scala/org/apache/pekko/http/impl/engine/http2/TelemetrySpiSpec.scala
@@ -94,13 +94,13 @@ abstract class TelemetrySpiSpec(useTls: Boolean) extends PekkoSpecWithMaterializ
 
     val http2ClientFlow =
       if (useTls) {
-        Http().connectionTo("akka.example.org")
+        Http().connectionTo("pekko.example.org")
           .withCustomHttpsConnectionContext(ExampleHttpContexts.exampleClientContext)
           .withClientConnectionSettings(ClientConnectionSettings(system).withTransport(
             ExampleHttpContexts.proxyTransport(serverBinding.localAddress)))
           .http2()
       } else {
-        Http().connectionTo("akka.example.org")
+        Http().connectionTo("pekko.example.org")
           .withClientConnectionSettings(ClientConnectionSettings(system).withTransport(
             ExampleHttpContexts.proxyTransport(serverBinding.localAddress)))
           .http2WithPriorKnowledge()


---------------------------------------------------------------------
To unsubscribe, e-mail: commits-unsubscribe@pekko.apache.org
For additional commands, e-mail: commits-help@pekko.apache.org
diff --git a/http-core/src/test/scala/org/apache/pekko/http/impl/engine/client/HostConnectionPoolSpec.scala b/http-core/src/test/scala/org/apache/pekko/http/impl/engine/client/HostConnectionPoolSpec.scala
index 343c465f1..30f79efaf 100644
--- a/http-core/src/test/scala/org/apache/pekko/http/impl/engine/client/HostConnectionPoolSpec.scala
+++ b/http-core/src/test/scala/org/apache/pekko/http/impl/engine/client/HostConnectionPoolSpec.scala
@@ -849,16 +849,17 @@ class HostConnectionPoolSpec extends PekkoSpecWithMaterializer(
   /**
    * Transport that uses actual top-level Http APIs to establish a HTTPS connection
    *
    * Currently requires an /etc/hosts entry that points akka.example.org to a locally bindable address.
    */
   case object PekkoHttpEngineTLS extends TopLevelApiClientServerImplementation {
     protected override def bindServerSource =
-      Http().newServerAt("akka.example.org", 0).enableHttps(ExampleHttpContexts.exampleServerContext).connectionSource()
+      Http().newServerAt("pekko.example.org", 0).enableHttps(
+        ExampleHttpContexts.exampleServerContext).connectionSource()
     protected def clientConnectionFlow(serverBinding: ServerBinding, connectionKillSwitch: SharedKillSwitch)
         : Flow[HttpRequest, HttpResponse, Future[Http.OutgoingConnection]] = {
       val clientConnectionSettings =
         ClientConnectionSettings(system).withTransport(new KillSwitchedClientTransport(connectionKillSwitch))
-      Http().outgoingConnectionUsingContext(host = "akka.example.org", port = serverBinding.localAddress.getPort,
+      Http().outgoingConnectionUsingContext(host = "pekko.example.org", port = serverBinding.localAddress.getPort,
         connectionContext = ExampleHttpContexts.exampleClientContext, settings = clientConnectionSettings)
     }
   }
@@ -849,16 +849,17 @@ class HostConnectionPoolSpec extends PekkoSpecWithMaterializer(
    * Transport that uses actual top-level Http APIs to establish a HTTPS connection
    *
-   * Currently requires an /etc/hosts entry that points akka.example.org to a locally bindable address.
+   * Currently requires an /etc/hosts entry that points pekko.example.org to a locally bindable address.
    */
   case object PekkoHttpEngineTLS extends TopLevelApiClientServerImplementation {
diff --git a/http-core/src/test/scala/org/apache/pekko/http/impl/engine/client/TlsEndpointVerificationSpec.scala b/http-core/src/test/scala/org/apache/pekko/http/impl/engine/client/TlsEndpointVerificationSpec.scala
index 0e4020b46..d30515fc8 100644
--- a/http-core/src/test/scala/org/apache/pekko/http/impl/engine/client/TlsEndpointVerificationSpec.scala
+++ b/http-core/src/test/scala/org/apache/pekko/http/impl/engine/client/TlsEndpointVerificationSpec.scala
@@ -41,24 +41,24 @@ class TlsEndpointVerificationSpec extends PekkoSpecWithMaterializer("""
 
   "The client implementation" should {
     "not accept certificates signed by unknown CA" in {
-      val pipe = pipeline(Http().defaultClientHttpsContext, hostname = "akka.example.org") // default context doesn't include custom CA
+      val pipe = pipeline(Http().defaultClientHttpsContext, hostname = "pekko.example.org") // default context doesn't include custom CA
 
-      whenReady(pipe(HttpRequest(uri = "https://akka.example.org/")).failed, timeout) { e =>
+      whenReady(pipe(HttpRequest(uri = "https://pekko.example.org/")).failed, timeout) { e =>
         e shouldBe an[Exception]
       }
     }
     "accept certificates signed by known CA" in {
-      val pipe = pipeline(ExampleHttpContexts.exampleClientContext, hostname = "akka.example.org") // example context does include custom CA
+      val pipe = pipeline(ExampleHttpContexts.exampleClientContext, hostname = "pekko.example.org") // example context does include custom CA
 
-      whenReady(pipe(HttpRequest(uri = "https://akka.example.org:8080/")), timeout) { response =>
+      whenReady(pipe(HttpRequest(uri = "https://pekko.example.org:8080/")), timeout) { response =>
         response.status shouldEqual StatusCodes.OK
         val tlsInfo = response.attribute(AttributeKeys.sslSession).get
-        tlsInfo.peerPrincipal.get.getName shouldEqual "CN=akka.example.org,O=Internet Widgits Pty Ltd,ST=Some-State,C=AU"
+        tlsInfo.peerPrincipal.get.getName shouldEqual "CN=pekko.example.org,O=Apache Foundation"
       }
     }
     "not accept certificates for foreign hosts" in {
       // We try to connect to 'hijack.de', but this connection is hijacked by a suspicious server
       // identifying as akka.example.org ;)
       val pipe = pipeline(ExampleHttpContexts.exampleClientContext, hostname = "hijack.de") // example context does include custom CA
 
       whenReady(pipe(HttpRequest(uri = "https://hijack.de/")).failed, timeout) { e =>
@@ -99,13 +99,13 @@ class TlsEndpointVerificationSpec extends PekkoSpecWithMaterializer("""
       val clientConnectionContext = ConnectionContext.httpsClient(createInsecureSslEngine _)
 
       // We try to connect to 'hijack.de', and even though this connection is hijacked by a suspicious server
       // identifying as akka.example.org we want to connect anyway
       val pipe = pipeline(clientConnectionContext, hostname = "hijack.de")
 
       whenReady(pipe(HttpRequest(uri = "https://hijack.de:8080/")), timeout) { response =>
         response.status shouldEqual StatusCodes.OK
         val tlsInfo = response.attribute(AttributeKeys.sslSession).get
-        tlsInfo.peerPrincipal.get.getName shouldEqual "CN=akka.example.org,O=Internet Widgits Pty Ltd,ST=Some-State,C=AU"
+        tlsInfo.peerPrincipal.get.getName shouldEqual "CN=pekko.example.org,O=Apache Foundation"
       }
     }
 
@@ -146,7 +146,7 @@ class TlsEndpointVerificationSpec extends PekkoSpecWithMaterializer("""
     val handler: HttpRequest => HttpResponse = { req =>
       // verify Tls-Session-Info header information
       val name = req.attribute(AttributeKeys.sslSession).flatMap(_.localPrincipal).map(_.getName)
-      if (name.exists(_ == "CN=akka.example.org,O=Internet Widgits Pty Ltd,ST=Some-State,C=AU")) HttpResponse()
+      if (name.contains("CN=pekko.example.org,O=Apache Foundation")) HttpResponse()
       else HttpResponse(StatusCodes.BadRequest, entity = "Tls-Session-Info header verification failed")
     }
 
@@ -41,24 +41,24 @@ class TlsEndpointVerificationSpec extends PekkoSpecWithMaterializer("""
     "not accept certificates for foreign hosts" in {
       // We try to connect to 'hijack.de', but this connection is hijacked by a suspicious server
-      // identifying as akka.example.org ;)
+      // identifying as pekko.example.org ;)
       val pipe = pipeline(ExampleHttpContexts.exampleClientContext, hostname = "hijack.de") // example context does include custom CA
 
@@ -99,13 +99,13 @@ class TlsEndpointVerificationSpec extends PekkoSpecWithMaterializer("""
 
       // We try to connect to 'hijack.de', and even though this connection is hijacked by a suspicious server
-      // identifying as akka.example.org we want to connect anyway
+      // identifying as pekko.example.org we want to connect anyway
       val pipe = pipeline(clientConnectionContext, hostname = "hijack.de")
 
diff --git a/http-core/src/test/scala/org/apache/pekko/http/scaladsl/ClientServerSpec.scala b/http-core/src/test/scala/org/apache/pekko/http/scaladsl/ClientServerSpec.scala
index b16b2e266..108679135 100644
--- a/http-core/src/test/scala/org/apache/pekko/http/scaladsl/ClientServerSpec.scala
+++ b/http-core/src/test/scala/org/apache/pekko/http/scaladsl/ClientServerSpec.scala
@@ -745,7 +745,7 @@ Host: example.com
         Http().newServerAt("localhost", 0).enableHttps(serverConnectionContext).bindFlow(handlerFlow)
           .futureValue
 
       // Disable hostname verification as ExampleHttpContexts.exampleClientContext sets hostname as akka.example.org
       val sslConfigSettings = SSLConfigSettings().withLoose(SSLLooseConfig().withDisableHostnameVerification(true))
       val sslConfig = PekkoSSLConfig().withSettings(sslConfigSettings)
       val sslContext = {
@@ -779,7 +779,7 @@ Host: example.com
     "complete a request/response over https when request has `Connection: close` set" in Utils.assertAllStagesStopped {
       // akka/akka-http#1219
       val serverToClientNetworkBufferSize = 1000
-      val request = HttpRequest(uri = s"https://akka.example.org", headers = headers.Connection("close") :: Nil)
+      val request = HttpRequest(uri = s"https://pekko.example.org", headers = headers.Connection("close") :: Nil)
 
       // settings adapting network buffer sizes
       val serverSettings =
@@ -828,7 +828,7 @@ Host: example.com
           Source.fromPublisher(source)))
 
       val serverSideTls = Http().sslTlsServerStage(ExampleHttpContexts.exampleServerContext)
-      val clientSideTls = Http().sslTlsClientStage(ExampleHttpContexts.exampleClientContext, "akka.example.org", 8080)
+      val clientSideTls = Http().sslTlsClientStage(ExampleHttpContexts.exampleClientContext, "pekko.example.org", 8080)
 
       val server: Flow[ByteString, ByteString, Any] =
         Http().serverLayer()
@@ -837,7 +837,7 @@ Host: example.com
           .join(Flow[HttpRequest].map(handler))
 
       val client =
-        Http().clientLayer(Host("akka.example.org", 8080))
+        Http().clientLayer(Host("pekko.example.org", 8080))
           .atop(clientSideTls)
 
       val killSwitch = KillSwitches.shared("kill-transport")
@@ -745,7 +745,7 @@ Host: example.com
           .futureValue
 
-      // Disable hostname verification as ExampleHttpContexts.exampleClientContext sets hostname as akka.example.org
+      // Disable hostname verification as ExampleHttpContexts.exampleClientContext sets hostname as pekko.example.org
       val sslConfigSettings = SSLConfigSettings().withLoose(SSLLooseConfig().withDisableHostnameVerification(true))
       val sslConfig = PekkoSSLConfig().withSettings(sslConfigSettings)